# Change History

## 2021.10.24

* Intermediate release with new dev tools
* No functional changes

## 0.0.5 (2021-05-11)

* More powerful external diff tool interface
* Decoupled helper functions
* Better test coverage
* Fifth release to PyPI

## 0.0.4 (2021-05-10)

* Added hook for external diff tool
* Simplified API
* Decoupled helper functions
* Enlarged test coverage
* Fourth release to PyPI

## 0.0.3 (2021-05-10)

* Hotfix for a typo in dependency declaration for PyPI
* Third release to PyPI

## 0.0.2 (2021-05-09)

* Set logging level to debug per `SUBTRACTOR_DEBUG` env variable
* Adjust mismatch percentage threshold per `SUBTRACTOR_THRESHOLD` env variable
* Support for single file and pair folder comparisons
* Implemented abort logic per `SUBTRACTOR_ABORT` env variable
* Real image pixel comparisons
* Zipped streaming implementation
* Second release on PyPI

## 0.0.1 (2021-05-06)

* Initial release on PyPI

